/** 3
 * foobar - a sample dummy function
 * This line is now the first of the description section.
 * Note that function parameters parm1 and parm2 are highlighted
 * in the generated man page.
 */
int foobar(char *parm1, int parm2)
{
   ...
   return 0;
}
